# Pixar Boost

[![CMake](https://img.shields.io/badge/CMake-3.21...3.31-blue.svg?logo=CMake&logoColor=blue)](https://cmake.org)
[![Linux](https://github.com/untwine/pxr-boost/actions/workflows/linux.yml/badge.svg?branch=main)](https://github.com/untwine/pxr-boost/actions/workflows/linux.yml)
[![MacOs](https://github.com/untwine/pxr-boost/actions/workflows/macos.yml/badge.svg?branch=main)](https://github.com/untwine/pxr-boost/actions/workflows/macos.yml)
[![Windows](https://github.com/untwine/pxr-boost/actions/workflows/windows.yml/badge.svg?branch=main)](https://github.com/untwine/pxr-boost/actions/workflows/windows.yml)
[![License](https://img.shields.io/badge/License-TOST-yellow.svg)](https://github.com/untwine/pxr-boost/blob/main/LICENSE.txt)

Boost.Python fork optimized for Pixar OpenUSD.

This repository is a decoupled version of the "boost" library from the
[OpenUSD](https://graphics.pixar.com/usd/release/index.html) library, created
by Pixar.

It is regularly rebased over the "release" branch of the original
[repository](https://github.com/PixarAnimationStudios/OpenUSD) to provide
explicit divergence information from the latest updates and is currently
synchronized with
[v25.02](https://github.com/PixarAnimationStudios/OpenUSD/releases/tag/v25.02).
